@@ -10,9 +10,9 @@ use IO::Uncompress::Unzip qw( unzip $UnzipError );
 use IO::Compress::Zip qw(zip $ZipError);
 use XML::LibXML;
 use Date::Parse 'str2time';
-use Math::Trig qw( deg2rad rad2deg great_circle_distance great_circle_bearing );
+use Math::Trig 1.23 qw( deg2rad rad2deg great_circle_distance great_circle_bearing );
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 our @EXPORT_OK = qw( tour kmz_to_xml xml_to_kmz load_kml read_path gather_points build_tour );
 
@@ -270,7 +270,7 @@ Geo::GoogleEarth::AutoTour - Generate Google Earth Camera Tours from Tracks and
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Geo-GoogleEarth-AutoTour.svg)](https://travis-ci.org/gryphonshafer/Geo-GoogleEarth-AutoTour)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Geo-GoogleEarth-AutoTour/badge.png)](https://coveralls.io/r/gryphonshafer/Geo-GoogleEarth-AutoTour)
